@@ -1,15 +1,15 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from ._ascii import ASCIIRenderer
-from ._base import dfs, dfs_filter, PayloadMerger, NoOp
+from ._base import dfs, dfs_filter, PayloadMerger
 from ._evaluation import Evaluator
 from ._einspec import EinsteinSpecGenerator
-from ._index_propagation import IndexPropagator
+from ._compile import Compiler
+from ._indexness import IndexnessAnalyzer
 from ._initialization import LeafInitializer
 from ._latex import LatexRenderer
 from ._elementwise import ElementwiseEvaluator
 from ._slicing_propagation import SlicingPropagator
-from ._shape import ShapeAnalyzer
 from ._vectorize import Vectorizer
 
 
@@ -17,15 +17,15 @@ __all__ = [
     'dfs',
     'dfs_filter',
     'ASCIIRenderer',
+    'Compiler',
     'Evaluator',
     'EinsteinSpecGenerator',
-    'IndexPropagator',
+    'IndexnessAnalyzer',
     'LeafInitializer',
     'LatexRenderer',
     'PayloadMerger',
-    'NoOp',
     'ElementwiseEvaluator',
     'SlicingPropagator',
-    'ShapeAnalyzer',
-    'Vectorizer'
+    'Vectorizer',
+    'PenaltyEvaluator',
 ]
