@@ -1,20 +1,30 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from ._base import TranscribeInterpreter
+from ._base import _as_payload, TranscribeInterpreter
 
 
 class ASCIIRenderer(TranscribeInterpreter):
     '''Creates ASCII representations for tensor expressions.'''
 
-    as_payload = TranscribeInterpreter.as_payload('ascii')
+    _traversal_order = TranscribeInterpreter.TraversalOrder.POST
+
+    as_payload = _as_payload('ascii')
+
+    @as_payload
+    def abstract_index_notation(self, tensor, indices, **kwargs):
+        return f'[{indices.ascii}]'
+
+    @as_payload
+    def abstract_binary(self, lhs, rhs, precedence, operator, **kwargs):
+        return f'{operator}'
 
     @as_payload
     def literal(self, value, **kwargs):
         return str(value)
 
     @as_payload
-    def tensor(self, abstract, **kwargs):
-        return str(abstract.symbol)
+    def tensor(self, decl, **kwargs):
+        return str(decl.symbol)
 
     @as_payload
     def index(self, item, bound, kron, **kwargs):
@@ -30,20 +40,20 @@ class ASCIIRenderer(TranscribeInterpreter):
         return ','.join([i.ascii for i in items])
 
     @as_payload
-    def index_notation(self, tensor, indices, **kwargs):
-        return f'{tensor.ascii}[{indices.ascii}]'
+    def indexed_tensor(self, tensor, indices, **kwargs):
+        return f'[{indices.ascii}]'
 
     @as_payload
     def call(self, f, x, **kwargs):
         return f
 
     @as_payload
-    def pow(self, base, exponent, **kwargs):
-        return 'pow'
+    def neg(self, x, **kwargs):
+        return ''
 
     @as_payload
-    def neg(self, x, **kwargs):
-        return '-'
+    def elem(self, lhs, rhs, precedence, operator, **kwargs):
+        return operator
 
     @as_payload
     def ein(self, lhs, rhs, precedence, reduction, pairwise, outidx, **kwargs):
@@ -53,3 +63,7 @@ class ASCIIRenderer(TranscribeInterpreter):
     @as_payload
     def tran(self, src, indices, **kwargs):
         return f'-> [{indices.ascii}]'
+
+    @as_payload
+    def abstract_dest(self, src, indices, **kwargs):
+        return f'-> [{indices.ascii}]'
